@@ -511,13 +511,17 @@ PanningMode::DispatchMouseEvent(nsITimer *timer, void *closure)
   event.refPoint.x = self->mFirstMousedownEvent.clientX * self->GetZoomLevel();
   event.refPoint.y = self->mFirstMousedownEvent.clientY * self->GetZoomLevel();
   event.time = PR_IntervalNow();
-  self->mViewManager->DispatchEvent(&event, &status);
+  self->mViewManager->DispatchEvent(&event, rootView, &status);
+ 	self->mViewManager->GetRootView(rootView);
+  NS_ENSURE_TRUE(rootView, );
   event.message = NS_MOUSE_BUTTON_DOWN;
   event.time = PR_IntervalNow();
-  self->mViewManager->DispatchEvent(&event, &status);
+  self->mViewManager->DispatchEvent(&event, rootView, &status);
+ 	self->mViewManager->GetRootView(rootView);
+  NS_ENSURE_TRUE(rootView, );
   event.message = NS_MOUSE_BUTTON_UP;
   event.time = PR_IntervalNow();
-  self->mViewManager->DispatchEvent(&event, &status);
+  self->mViewManager->DispatchEvent(&event, rootView, &status);
 }
 
 PRBool
